@@ -42,9 +42,9 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Thu Mar 13 13:52:57 EET 2008
+## Configuration time: Thu Dec 18 15:22:52 EET 2008
 ## Configured by     : Debian Project
-## Target system     : linux eewi 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 i686 gnulinux 
+## Target system     : linux quart 2.6.18-6-686-bigmem #1 smp sun feb 10 22:21:07 utc 2008 i486 gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -103,7 +103,7 @@ installprivlib='/usr/share/perl/5.8'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt'
 osname='linux'
-osvers='2.6.18-5-686-bigmem'
+osvers='2.6.18-6-686-bigmem'
 prefix='/usr'
 privlibexp='/usr/share/perl/5.8'
 sharpbang='#!'
@@ -168,7 +168,7 @@ ccsymbols=''
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Thu Mar 13 13:52:57 EET 2008'
+cf_time='Thu Dec 18 15:22:52 EET 2008'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -220,7 +220,7 @@ cpplast='-'
 cppminus='-'
 cpprun='cc -E'
 cppstdin='cc -E'
-cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=4 __GNUC__=3 __GNUC_MINOR__=4 __GNU_LIBRARY__=6 _GNU_SOURCE=1 _LARGEFILE64_SOURCE=1 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=200112 _POSIX_SOURCE=1 _REENTRANT=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_GNU=1 __USE_LARGEFILE=1 __USE_LARGEFILE64=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_REENTRANT=1 __USE_SVID=1 __USE_UNIX98=1 __USE_XOPEN=1 __USE_XOPEN_EXTENDED=1 _XOPEN_SOURCE=600 _XOPEN_SOURCE_EXTENDED=1 i386=1 __i386=1 __i386__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
+cppsymbols='__ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=5 __GNUC__=4 __GNUC_MINOR__=2 __GNU_LIBRARY__=6 _GNU_SOURCE=1 _LARGEFILE64_SOURCE=1 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=200112 _POSIX_SOURCE=1 _REENTRANT=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_GNU=1 __USE_LARGEFILE=1 __USE_LARGEFILE64=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_REENTRANT=1 __USE_SVID=1 __USE_UNIX98=1 __USE_XOPEN=1 __USE_XOPEN_EXTENDED=1 _XOPEN_SOURCE=600 _XOPEN_SOURCE_EXTENDED=1 i386=1 __i386=1 __i386__=1 linux=1 __linux=1 __linux__=1 unix=1 __unix=1 __unix__=1'
 crypt_r_proto='REENTRANT_PROTO_B_CCS'
 cryptlib=''
 csh='csh'
@@ -668,7 +668,7 @@ full_csh='csh'
 full_sed='/scratchbox/tools/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.4.4 (release) (CodeSourcery ARM 2005q3-2)'
+gccversion='4.2.1'
 getgrent_r_proto='REENTRANT_PROTO_I_SBWR'
 getgrgid_r_proto='REENTRANT_PROTO_I_TSBWR'
 getgrnam_r_proto='REENTRANT_PROTO_I_CSBWR'
@@ -889,10 +889,10 @@ modetype='mode_t'
 more='more'
 multiarch='undef'
 mv=''
-myarchname='i686-linux'
+myarchname='i486-linux'
 mydomain=''
 myhostname='localhost'
-myuname='linux eewi 2.6.18-5-686-bigmem #1 smp wed oct 3 01:22:56 utc 2007 i686 gnulinux '
+myuname='linux quart 2.6.18-6-686-bigmem #1 smp sun feb 10 22:21:07 utc 2008 i486 gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -916,7 +916,7 @@ nvtype='double'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 old_pthread_create_joinable=''
-optimize='-O3'
+optimize='-O2'
 orderlib='false'
 otherlibdirs=' '
 package='perl5'
@@ -1307,7 +1307,7 @@ tie %Config, 'Config', {
     'libpth' => '/usr/local/lib /lib /usr/lib',
     'libs' => '-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt',
     'osname' => 'linux',
-    'osvers' => '2.6.18-5-686-bigmem',
+    'osvers' => '2.6.18-6-686-bigmem',
     'prefix' => '/usr',
     'privlibexp' => '/usr/share/perl/5.8',
     'sharpbang' => '#!',
